@@ -14,7 +14,7 @@ FILE* fopen_printf(char* mode, char* fmt, ...)
 {
  va_list ap;
  char fnam[PATH];
- debug("%s:%d fopen_printf",__FILE__,__LINE__);
+ debug("%s:%d fopen_printf(%s,%s)",__FILE__,__LINE__,mode,fmt);
  if (!fmt) return NULL;
  va_start(ap,fmt);
  vsprintf(fnam,fmt,ap);
@@ -76,7 +76,7 @@ int debug(char* fmt, ...)
 int fatal(char* fmt, ...)
 {
  va_list ap;
- debug("%s:%d fatal",__FILE__,__LINE__);
+ debug("%s:%d fatal(%s)",__FILE__,__LINE__,fmt);
  if (!fmt) return -1;
  va_start(ap,fmt);
  printf("\n\nPANIC\n\t%c%cfatal: ",7,7);
@@ -85,13 +85,18 @@ int fatal(char* fmt, ...)
  va_end(ap);
  printf("\nSend a bug report to: morgothdbma@o2.pl\n");
  fflush(stdout);
+#ifdef CORE_DUMP
+ printf("Core dump for user request, DEBUG ME IN GDB\n");
+ abort();
+#else
  exit(1);
+#endif
 }
 
 int fatal_here(char* file, int line, char* fmt, ...)
 {
  va_list ap;
- debug("%s:%d fatal",__FILE__,__LINE__);
+ debug("%s:%d fatal_here(%s,%d,%d)",__FILE__,__LINE__,file,line,fmt);
  if (!fmt) return -1;
  va_start(ap,fmt);
  printf("\n\nPANIC FROM FILE: %s, LINE: %d\n\t%c%cfatal: ",file,line,7,7);
@@ -114,7 +119,7 @@ void downcase(char* ptr)
 {
  int i;
  int s;
- debug("%s:%d downcase",__FILE__,__LINE__);
+ debug("%s:%d downcase(%s)",__FILE__,__LINE__,ptr);
  if (!ptr) return;
  s = strlen(ptr);
  for (i=0;i<s;i++) if (ptr[i]>='A' && ptr[i]<='Z') ptr[i]+=0x20;
@@ -125,7 +130,7 @@ int error(char* fmt, ...)
 {
  va_list ap;
  int err;
- debug("%s:%d error",__FILE__,__LINE__);
+ debug("%s:%d error(%s)",__FILE__,__LINE__,fmt);
  if (!fmt) return -1;
  va_start(ap,fmt);
  printf("error: ");
@@ -141,7 +146,7 @@ int warn(char* fmt, ...)
 {
  va_list ap;
  int err;
- debug("%s:%d warn",__FILE__,__LINE__);
+ debug("%s:%d warn(%s)",__FILE__,__LINE__,fmt);
  if (!fmt) return -1;
  va_start(ap,fmt);
  printf("warning: ");
@@ -157,7 +162,7 @@ int system_printf(char* fmt, ...)
 {
  va_list ap;
  char syscmd[MAX_SYSTEM_CMD];
- debug("%s:%d system_printf",__FILE__,__LINE__);
+ debug("%s:%d system_printf(%s)",__FILE__,__LINE__,fmt);
  debug("system_printf: %s", fmt);
  if (!fmt) return -1;
  va_start(ap,fmt);
@@ -170,7 +175,7 @@ int system_printf(char* fmt, ...)
 void print_results(char*** res, int a, int b)
 {
  int i,j;
- debug("%s:%d print_results",__FILE__,__LINE__);
+ debug("%s:%d print_results(%p,%d,%d)",__FILE__,__LINE__,res,a,b);
  ln();
  if (!res) return;
  for (i=0;i<a;i++)
