@@ -15,7 +15,8 @@
 #include "main.h"
 #include "pgxexplorer.h"
 #include "common.h"
-
+#include "mmsystem.h"
 void cmenu_browse_all(GtkWidget* w, gpointer data);
-
+void create_pbar(char*);
+void destroy_pbar();
 #endif
