@@ -18,7 +18,7 @@ static int col = 0;
 int strhasdot(char* str)
 {
  int l,i;
- debug("%s:%d strhasdot",__FILE__,__LINE__);
+ debug("%s:%d strhasdot(%s)",__FILE__,__LINE__,str);
  if (!str) return 0;
  l = strlen(str)-1;
  for (i=l;i>=0;i--)
@@ -32,6 +32,7 @@ int strhasdot(char* str)
 
 void destroy_widget(GtkWidget* w)
 {
+ debug("%s:%d destroy_widget()",__FILE__,__LINE__);
  if (GTK_IS_WIDGET(w)) gtk_widget_destroy(w);
 }
 
@@ -40,7 +41,7 @@ int mask_match()
  char tmps[MAX_ENTRY_LENGTH];
  char tmpm[MASK_LENGTH];
  int i,j;
- debug("%s:%d mask_match",__FILE__,__LINE__);
+ debug("%s:%d mask_match()",__FILE__,__LINE__);
  strcpy(tmps, tentry);
  strcpy(tmpm, fmask);
  downcase(tmps);
@@ -69,7 +70,7 @@ int mask_match()
 
 void destroy_fs(GtkWidget* w, gpointer d)
 {
- debug("%s:%d destroy_fs",__FILE__,__LINE__);
+ debug("%s:%d destroy_fs()",__FILE__,__LINE__);
  gtk_main_quit();
  if (!d) return;
  destroy_widget((GtkWidget*)(d));
@@ -78,7 +79,7 @@ void destroy_fs(GtkWidget* w, gpointer d)
 
 void cancel_fs(GtkWidget* w, gpointer d)
 {
- debug("%s:%d cancel_fs",__FILE__,__LINE__);
+ debug("%s:%d cancel_fs()",__FILE__,__LINE__);
  gtk_main_quit();
  if (!d) return;
  destroy_widget((GtkWidget*)(d));
@@ -88,7 +89,7 @@ void cancel_fs(GtkWidget* w, gpointer d)
 
 void ok_fs(GtkWidget* w, gpointer d)
 {
- debug("%s:%d ok_fs",__FILE__,__LINE__);
+ debug("%s:%d ok_fs()",__FILE__,__LINE__);
  if (!d) return;
  strcpy(tentry,gtk_file_selection_get_filename((GTK_FILE_SELECTION(d))));
  if (!mask_match()) strcpy(tentry,"");
@@ -99,7 +100,7 @@ void ok_fs(GtkWidget* w, gpointer d)
 
 gint delete_event_proc()
 {
- debug("%s:%d delete_event_proc",__FILE__,__LINE__);
+ debug("%s:%d delete_event_proc()",__FILE__,__LINE__);
  answer = ANSWER_NO;
  strcpy(tentry, "");
  gtk_main_quit();
@@ -109,7 +110,7 @@ gint delete_event_proc()
 
 gint delete_combos_proc(GtkWidget* w, gpointer d)
 {
- debug("%s:%d delete_combos_proc",__FILE__,__LINE__);
+ debug("%s:%d delete_combos_proc()",__FILE__,__LINE__);
  answer = ANSWER_NO;
  strcpy(tentry, "");
  gtk_main_quit();
@@ -121,7 +122,7 @@ gint delete_combos_proc(GtkWidget* w, gpointer d)
 
 void ok_proc(GtkWidget* w, gpointer d)
 {
- debug("%s:%d ok_proc",__FILE__,__LINE__);
+ debug("%s:%d ok_proc()",__FILE__,__LINE__);
  gtk_main_quit();
  if (!d) return;
  destroy_widget((GtkWidget*)(d));
@@ -130,7 +131,7 @@ void ok_proc(GtkWidget* w, gpointer d)
 
 void ok_combo_proc(GtkWidget* w, gpointer cmb)
 {
- debug("%s:%d ok_combo_proc",__FILE__,__LINE__);
+ debug("%s:%d ok_combo_proc()",__FILE__,__LINE__);
  if (!cmb) return;
  strcpy(tentry,gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(cmb)->entry)));
  gtk_main_quit();
@@ -141,14 +142,14 @@ void ok_combo_proc(GtkWidget* w, gpointer cmb)
 
 void entry_changed_proc(GtkWidget* w, gpointer d)
 {
- debug("%s:%d entry_changed_proc",__FILE__,__LINE__);
+ debug("%s:%d entry_changed_proc()",__FILE__,__LINE__);
  strcpy(tentry,gtk_entry_get_text(GTK_ENTRY(w)));
 }
 
 
 void entry_proc(GtkWidget* w, gpointer d)
 {
- debug("%s:%d entry_proc",__FILE__,__LINE__);
+ debug("%s:%d entry_proc()",__FILE__,__LINE__);
  strcpy(tentry,gtk_entry_get_text(GTK_ENTRY(w)));
  gtk_main_quit();
  if (!d) return;
@@ -158,7 +159,7 @@ void entry_proc(GtkWidget* w, gpointer d)
 
 void yes_proc(GtkWidget* w, gpointer d)
 {
- debug("%s:%d yes_proc",__FILE__,__LINE__);
+ debug("%s:%d yes_proc()",__FILE__,__LINE__);
  answer = ANSWER_YES;
  gtk_main_quit();
  if (!d) return;
@@ -170,7 +171,7 @@ void return_value(GtkWidget* w, gpointer ptr)
  GtkAdjustment* adj;
  struct carrier* car;
  car = (struct carrier*)ptr;
- debug("%s:%d yes_proc",__FILE__,__LINE__);
+ debug("%s:%d return_value()",__FILE__,__LINE__);
  adj = gtk_range_get_adjustment(GTK_RANGE(&(GTK_SCALE(car->ptr)->range)));
  answer = (int)(adj->value);
  gtk_main_quit();
@@ -180,7 +181,7 @@ void return_value(GtkWidget* w, gpointer ptr)
 
 void no_proc(GtkWidget* w, gpointer d)
 {
- debug("%s:%d no_proc",__FILE__,__LINE__);
+ debug("%s:%d no_proc()",__FILE__,__LINE__);
  answer = ANSWER_NO;
  gtk_main_quit();
  if (!d) return;
@@ -192,7 +193,7 @@ char* gtk_dialog_getfile_printf(const char* mask, const char* fmt, ...)
 {
  va_list ap;
  char msg[MAX_MSG_LENGTH];
- debug("%s:%d gtk_dialog_getfile_printf",__FILE__,__LINE__);
+ debug("%s:%d gtk_dialog_getfile_printf(%s,%s)",__FILE__,__LINE__,mask,fmt);
  if (!fmt) return NULL;
  va_start(ap, fmt);
  vsprintf(msg,fmt,ap);
@@ -205,7 +206,7 @@ char* gtk_dialog_gettext_printf(const char* fmt, ...)
 {
  va_list ap;
  char msg[MAX_MSG_LENGTH];
- debug("%s:%d gtk_dialog_gettext_printf",__FILE__,__LINE__);
+ debug("%s:%d gtk_dialog_gettext_printf(%s)",__FILE__,__LINE__,fmt);
  if (!fmt) return NULL;
  va_start(ap, fmt);
  vsprintf(msg,fmt,ap);
@@ -218,7 +219,7 @@ char* gtk_dialog_gettext_big_printf(const char* fmt, ...)
 {
  va_list ap;
  char msg[MAX_MSG_LENGTH];
- debug("%s:%d gtk_dialog_gettext_big_printf",__FILE__,__LINE__);
+ debug("%s:%d gtk_dialog_gettext_big_printf(%s)",__FILE__,__LINE__,fmt);
  if (!fmt) return NULL;
  va_start(ap, fmt);
  vsprintf(msg,fmt,ap);
@@ -230,7 +231,7 @@ int gtk_dialog_getnum_printf(int a, int b, char* fmt, ...)
 {
  va_list ap;
  char msg[MAX_MSG_LENGTH];
- debug("%s:%d gtk_dialog_getnum_printf",__FILE__,__LINE__);
+ debug("%s:%d gtk_dialog_getnum_printf(%d,%d,%s)",__FILE__,__LINE__,a,b,fmt);
  if (!fmt) return -1;
  va_start(ap, fmt);
  vsprintf(msg,fmt,ap);
@@ -244,7 +245,7 @@ int gtk_dialog_getnum(int ua, int ub, char* msg)
  GtkObject *adj;
  struct carrier* car;
  int a,b;
- debug("%s:%d gtk_dialog_getnum",__FILE__,__LINE__);
+ debug("%s:%d gtk_dialog_getnum(%d,%d,%s)",__FILE__,__LINE__,ua,ub,msg);
  a = (ua<=ub)?ua:ub;
  b = (ua>ub) ?ua:ub;
  if (a==b) return a;
@@ -279,7 +280,7 @@ int gtk_dialog_getnum(int ua, int ub, char* msg)
 char* gtk_dialog_getfile(const char* mask, const char* question)
 {
  GtkWidget* filew, *flist;
- debug("%s:%d gtk_dialog_getfile",__FILE__,__LINE__);
+ debug("%s:%d gtk_dialog_getfile(%s,%s)",__FILE__,__LINE__,mask,question);
  strcpy(fmask,"");
  if (!question)  filew = gtk_file_selection_new("NULL");
  if (strlen(mask)>=MASK_LENGTH) { error("mask too long %s:%d", __FILE__,__LINE__); return NULL; }
@@ -302,7 +303,7 @@ char* gtk_dialog_getfile(const char* mask, const char* question)
 char* gtk_dialog_gettext_big(const char* question)
 {
  GtkWidget* dialog, *label, *button, *entry;
- debug("%s:%d gtk_dialog_gettext_big",__FILE__,__LINE__);
+ debug("%s:%d gtk_dialog_gettext_big(%s)",__FILE__,__LINE__,question?question:"null");
  if (!question) warn("question=NULL: %s:%d",__FILE__,__LINE__);
  strcpy(tentry, "");
  dialog = gtk_dialog_new();
@@ -332,7 +333,7 @@ char* gtk_dialog_gettext_big(const char* question)
 char* gtk_dialog_getpass(const char* question)
 {
  GtkWidget* dialog, *label, *button, *entry;
- debug("%s:%d gtk_dialog_gettext",__FILE__,__LINE__);
+ debug("%s:%d gtk_dialog_gettext(%s)",__FILE__,__LINE__,question?question:"null");
  if (!question) warn("question=NULL: %s:%d",__FILE__,__LINE__);
  strcpy(tentry, "");
  dialog = gtk_dialog_new();
@@ -363,7 +364,7 @@ char* gtk_dialog_getpass(const char* question)
 char* gtk_dialog_gettext(const char* question)
 {
  GtkWidget* dialog, *label, *button, *entry;
- debug("%s:%d gtk_dialog_gettext",__FILE__,__LINE__);
+ debug("%s:%d gtk_dialog_gettext(%s)",__FILE__,__LINE__,question?question:"null");
  if (!question) warn("question=NULL: %s:%d",__FILE__,__LINE__);
  strcpy(tentry, "");
  dialog = gtk_dialog_new();
@@ -395,7 +396,7 @@ void gtk_dialog_printf(const char* fmt, ...)
 {
  va_list ap;
  char msg[MAX_MSG_LENGTH];
- debug("%s:%d gtk_dialog_printf",__FILE__,__LINE__);
+ debug("%s:%d gtk_dialog_printf(%s)",__FILE__,__LINE__,fmt);
  if (!fmt) return ;
  va_start(ap, fmt);
  vsprintf(msg,fmt,ap);
@@ -410,7 +411,7 @@ void gtk_dialog_printf_big_with_title(const char* title, const char* fmt, ...)
  GtkWidget* dialog, *label, *button;
  char msg[MAX_MSG_LENGTH];
  va_list ap;
- debug("%s:%d gtk_dialog_printf_big_with_title",__FILE__,__LINE__);
+ debug("%s:%d gtk_dialog_printf_big_with_title(%s,%s)",__FILE__,__LINE__,title?title:"null",fmt);
  if (!title) warn("title=NULL: %s:%d",__FILE__,__LINE__);
  va_start(ap,fmt);
  vsprintf(msg,fmt,ap);
@@ -438,7 +439,7 @@ void gtk_dialog_printf_big(const char* fmt, ...)
  GtkWidget* dialog, *label, *button;
  char msg[MAX_MSG_LENGTH];
  va_list ap;
- debug("%s:%d gtk_dialog_big_printf",__FILE__,__LINE__);
+ debug("%s:%d gtk_dialog_big_printf(%s)",__FILE__,__LINE__,fmt);
  if (!fmt) return ;
  va_start(ap,fmt);
  vsprintf(msg,fmt,ap);
@@ -466,7 +467,7 @@ void gtk_dialog_printf_with_title(const char* title, const char* fmt, ...)
  GtkWidget* dialog, *label, *button;
  char msg[MAX_MSG_LENGTH];
  va_list ap;
- debug("%s:%d gtk_dialog_printf_with_title",__FILE__,__LINE__);
+ debug("%s:%d gtk_dialog_printf_with_title(%s,%s)",__FILE__,__LINE__,title,fmt);
  if (!fmt) return;
  va_start(ap,fmt);
  vsprintf(msg,fmt,ap);
@@ -492,7 +493,7 @@ void gtk_dialog_printf_with_title(const char* title, const char* fmt, ...)
 void gtk_dialog_mbox(const char* title, const char* msg)
 {
  GtkWidget* dialog, *label, *button;
- debug("%s:%d gtk_dialog_mbox",__FILE__,__LINE__);
+ debug("%s:%d gtk_dialog_mbox(%s,%s)",__FILE__,__LINE__,title,msg);
  if (!msg || !title) return;
  dialog = gtk_dialog_new();
  gtk_window_set_title(GTK_WINDOW(dialog), title);
@@ -517,7 +518,7 @@ int gtk_dialog_yes_no_printf(const char* fmt, ...)
  GtkWidget* dialog, *label, *button_yes, *button_no;
  char question[MAX_MSG_LENGTH];
  va_list ap;
- debug("%s:%d gtk_dialog_yes_no_printf",__FILE__,__LINE__);
+ debug("%s:%d gtk_dialog_yes_no_printf(%s)",__FILE__,__LINE__,fmt);
  if (!fmt) return 0;
  va_start(ap,fmt);
  vsprintf(question,fmt,ap);
@@ -548,7 +549,7 @@ int gtk_dialog_yes_no_printf(const char* fmt, ...)
 int gtk_dialog_with_2_buttons(const char* question, char* but1, char* but2)
 {
  GtkWidget* dialog, *label, *button_yes, *button_no;
- debug("%s:%d gtk_dialog_with_2_buttons",__FILE__,__LINE__);
+ debug("%s:%d gtk_dialog_with_2_buttons()",__FILE__,__LINE__);
  if (!question || !but1 || !but2) { warn("parameters! %s:%d", __FILE__,__LINE__); return 0; }
  dialog = gtk_dialog_new();
  gtk_window_set_title(GTK_WINDOW(dialog), "Confirmation needed.");
@@ -576,7 +577,7 @@ int gtk_dialog_with_2_buttons(const char* question, char* but1, char* but2)
 int gtk_dialog_yes_no(const char* question)
 {
  GtkWidget* dialog, *label, *button_yes, *button_no;
- debug("%s:%d gtk_dialog_yes_no",__FILE__,__LINE__);
+ debug("%s:%d gtk_dialog_yes_no(%s)",__FILE__,__LINE__,question);
  if (!question) { warn("question=NULL, %s:%d", __FILE__,__LINE__); return 0; }
  dialog = gtk_dialog_new();
  gtk_window_set_title(GTK_WINDOW(dialog), "Confirmation needed.");
@@ -606,7 +607,7 @@ int setup_combo(PGconn* c, GtkWidget* w, GtkWidget** cmb)
  char errstr[MAX_QUERY_LENGTH];
  int i;
  GList* list;
- debug("%s:%d setup_combo",__FILE__,__LINE__);
+ debug("%s:%d setup_combo()",__FILE__,__LINE__);
  list = NULL;
  if (!c || !w) error("setup_combo, %s:%d",__FILE__,__LINE__);
  ptr=p3c_execute_printf(c,&row,&col,errstr, 0, "SELECT datname FROM pg_database");
@@ -625,6 +626,7 @@ int setup_combo(PGconn* c, GtkWidget* w, GtkWidget** cmb)
  gtk_combo_set_popdown_strings(GTK_COMBO(*cmb), list);
  g_list_free(list);
  //free_p3c(&ptr, row, col);	//XXX can we free it? WE CANT
+ 				//will be freed later
  return 0;
 }
 
@@ -634,7 +636,7 @@ char* gtk_dialog_getdbs(PGconn* connection, char* fmt, ...)
  GtkWidget* dialog, *combo, *button, *label;
  char msg[MAX_MSG_LENGTH];
  va_list ap;
- debug("%s:%d gtk_dialog_getdbs",__FILE__,__LINE__);
+ debug("%s:%d gtk_dialog_getdbs(%s)",__FILE__,__LINE__,fmt);
  if (!connection || !fmt) error("gtk_getdbs, params: %s:%d", __FILE__,__LINE__);
  va_start(ap,fmt);
  vsprintf(msg,fmt,ap);
