@@ -78,6 +78,9 @@ int numeric(char* val);
 void create_table(GtkWidget* w, gpointer opt);
 void tdrop_table(GtkWidget* w, gpointer opt);
 void tdrop_view(GtkWidget* w, gpointer opt);
+void tinsert(GtkWidget* w, gpointer opt);
+void tdelete(GtkWidget* w, gpointer opt);
+void wizards(GtkWidget* w, gpointer opt);
 void drop_table(char*, int);
 void drop_view(char*, int);
 void drop_tables();
