@@ -21,7 +21,7 @@ int connAlive(PGconn* c)
 {
  PGresult* r;
  int stat;
- debug("%s:%d connAlive", __FILE__,__LINE__);
+ debug("%s:%d connAlive(%p)", __FILE__,__LINE__,c);
  ping_conn=1;
  alarm_clock(timeout);
  r= PQexec(c, "SELECT datname FROM pg_database");
@@ -43,7 +43,7 @@ int connAlive(PGconn* c)
 
 void disconnect_db(PGconn** c)
 {
- debug("%s:%d disconnect_db", __FILE__,__LINE__);
+ debug("%s:%d disconnect_db(%p)", __FILE__,__LINE__,*c);
  if (*c) PQfinish(*c);
  else warn("connect is null: %s:%d", __FILE__,__LINE__);
  *c = NULL;
@@ -55,7 +55,7 @@ PGconn* connect_db(char* arg, char* pass)
  PGconn* conn;
  char* strarg;
  conn=0;
- debug("%s:%d connect_db", __FILE__,__LINE__);
+ debug("%s:%d connect_db(%s,***)", __FILE__,__LINE__,arg?arg:"null");
  strarg = (char*)malloc(strlen(arg)+64+(pass?strlen(pass):1));
  debug("\nconnect to database %s\n", arg);
  if (!pass) sprintf(strarg,"dbname=template1");
@@ -89,7 +89,7 @@ PGconn* gtk_connect_db(char* arg, char* pass, char* errstr)
  PGconn* conn;
  char* strarg;
  conn=0;
- debug("%s:%d gtk_connect_db", __FILE__,__LINE__);
+ debug("%s:%d gtk_connect_db(%s,***)", __FILE__,__LINE__,arg?arg:"null");
  strarg = (char*)malloc(strlen(arg)+64+(pass?strlen(pass):1));
  if (!pass) sprintf(strarg,"dbname=template1");
  else       sprintf(strarg,"dbname=template1 password='%s'", pass);
@@ -118,7 +118,7 @@ PGconn* gtk_connect_db(char* arg, char* pass, char* errstr)
 
 void clear_result(PGresult** r)
 {
- debug("%s:%d clear_result", __FILE__,__LINE__);
+ debug("%s:%d clear_result()", __FILE__,__LINE__);
  if (*r) PQclear(*r);
  *r=0;
 }
@@ -128,7 +128,7 @@ PGresult* execute_silent_query(PGconn* c,  char* query)
 {
  PGresult* r;
  int stat;
- debug("%s:%d execute_silent_query", __FILE__,__LINE__);
+ debug("%s:%d execute_silent_query(%s)", __FILE__,__LINE__,query);
  debug("SQLquery: \"%s\"\n", query);
  if (!connAlive(c)) { debug("connection dead!\n"); return NULL; }
  if (!query)
@@ -159,7 +159,7 @@ char*** p3c_execute_printf(PGconn* c,int* row, int* col, char* errstr, int want_
  va_list ap;
  char*** ret;
  char msg[MAX_QUERY_LENGTH*2];
- debug("%s:%d p3c_execute_printf", __FILE__,__LINE__);
+ debug("%s:%d p3c_execute_printf(%s, %d)", __FILE__,__LINE__,fmt,want_meta);
  if (!c) { error("no connection"); return NULL; }
  va_start(ap, fmt);
  vsprintf(msg,fmt,ap);
@@ -173,7 +173,7 @@ char*** dmp3c_execute_printf(PGconn* c,int* row, int* col, char* errstr, int wan
  va_list ap;
  char*** ret;
  char msg[MAX_QUERY_LENGTH*2];
- debug("%s:%d dmp3c_execute_printf called from %s:%d", __FILE__,__LINE__,file,line);
+ debug("%s:%d dmp3c_execute_printf(%s,%d) called from %s:%d", __FILE__,__LINE__,fmt,want_meta,file,line);
  if (!c) { error("no connection"); return NULL; }
  va_start(ap, fmt);
  vsprintf(msg,fmt,ap);
@@ -187,7 +187,7 @@ char*** dmem_p3c_execute_printf(struct dmem_list** mem, PGconn* c,int* row, int*
  va_list ap;
  char*** ret;
  char msg[MAX_QUERY_LENGTH*2];
- debug("%s:%d dmem_p3c_execute_printf called from %s:%d", __FILE__,__LINE__,file,line);
+ debug("%s:%d dmem_p3c_execute_printf(%s,%d) called from %s:%d", __FILE__,__LINE__,fmt,want_meta,file,line);
  if (!c) { error("no connection"); return NULL; }
  va_start(ap, fmt);
  vsprintf(msg,fmt,ap);
@@ -201,7 +201,7 @@ char*** mp3c_execute_printf(PGconn* c,int* row, int* col, char* errstr, int want
  va_list ap;
  char*** ret;
  char msg[MAX_QUERY_LENGTH*2];
- debug("%s:%d mp3c_execute_printf", __FILE__,__LINE__);
+ debug("%s:%d mp3c_execute_printf(%s,%d)", __FILE__,__LINE__,fmt,want_meta);
  if (!c) { error("no connection"); return NULL; }
  va_start(ap, fmt);
  vsprintf(msg,fmt,ap);
@@ -215,7 +215,7 @@ char*** mem_p3c_execute_printf(struct mem_list** mem, PGconn* c,int* row, int* c
  va_list ap;
  char*** ret;
  char msg[MAX_QUERY_LENGTH*2];
- debug("%s:%d mem_p3c_execute_printf", __FILE__,__LINE__);
+ debug("%s:%d mem_p3c_execute_printf(%s,%d)", __FILE__,__LINE__,fmt,want_meta);
  if (!c) { error("no connection"); return NULL; }
  va_start(ap, fmt);
  vsprintf(msg,fmt,ap);
@@ -230,7 +230,7 @@ void dmem_execute_printf(struct dmem_list** mem, PGconn* c, char**** res, int* r
  va_list ap;
  char query[MAX_QUERY_LENGTH*2];
  PGresult* r;
- debug("%s:%d mem_execute_printf called from %s:%d", __FILE__,__LINE__,file,line);
+ debug("%s:%d mem_execute_printf(%s,%d) called from %s:%d", __FILE__,__LINE__,fmt,want_meta,file,line);
  va_start(ap, fmt);
  vsprintf(query,fmt,ap);
  va_end(ap);
@@ -277,7 +277,7 @@ void mem_execute_printf(struct mem_list** mem, PGconn* c, char**** res, int* row
  va_list ap;
  char query[MAX_QUERY_LENGTH*2];
  PGresult* r;
- debug("%s:%d mem_execute_printf", __FILE__,__LINE__);
+ debug("%s:%d mem_execute_printf(%s,%d)", __FILE__,__LINE__,fmt,want_meta);
  va_start(ap, fmt);
  vsprintf(query,fmt,ap);
  va_end(ap);
@@ -324,7 +324,7 @@ void dmexecute_printf(PGconn* c, char**** res, int* row, int* col, char* errstr,
  va_list ap;
  char query[MAX_QUERY_LENGTH*2];
  PGresult* r;
- debug("%s:%d dmexecute_printf called from %s:%d", __FILE__,__LINE__,file,line);
+ debug("%s:%d dmexecute_printf(%s,%d) called from %s:%d", __FILE__,__LINE__,fmt,want_meta,file,line);
  va_start(ap, fmt);
  vsprintf(query,fmt,ap);
  va_end(ap);
@@ -371,7 +371,7 @@ void mexecute_printf(PGconn* c, char**** res, int* row, int* col, char* errstr,
  va_list ap;
  char query[MAX_QUERY_LENGTH*2];
  PGresult* r;
- debug("%s:%d mexecute_printf", __FILE__,__LINE__);
+ debug("%s:%d mexecute_printf(%s,%d)", __FILE__,__LINE__,fmt,want_meta);
  va_start(ap, fmt);
  vsprintf(query,fmt,ap);
  va_end(ap);
@@ -418,7 +418,7 @@ void execute_printf(PGconn* c, char**** res, int* row, int* col, char* errstr, i
  va_list ap;
  char query[MAX_QUERY_LENGTH*2];
  PGresult* r;
- debug("%s:%d execute_printf", __FILE__,__LINE__);
+ debug("%s:%d execute_printf(%s,%d)", __FILE__,__LINE__,fmt,want_meta);
  va_start(ap, fmt);
  vsprintf(query,fmt,ap);
  va_end(ap);
@@ -465,7 +465,7 @@ void execute_printf_query(PGconn* c,PGresult** r, char* errstr, char* fmt,...)
  int stat;
  va_list ap;
  char query[MAX_QUERY_LENGTH*2];
- debug("%s:%d execute_printf_query", __FILE__,__LINE__);
+ debug("%s:%d execute_printf_query(%s)", __FILE__,__LINE__,fmt);
  va_start(ap, fmt);
  vsprintf(query,fmt,ap);
  va_end(ap);
@@ -505,7 +505,7 @@ int get_db_tables(PGconn* c, char*** dat, int* ntabs, int want_all_elems)
  int row,col,i;
  char errstr[MAX_QUERY_LENGTH+100];
  data = *dat;
- debug("%s:%d get_db_tables", __FILE__,__LINE__);
+ debug("%s:%d get_db_tables(%d)", __FILE__,__LINE__,want_all_elems);
  if (!want_all_elems)
  execute_printf(c, &res, &row, &col, errstr, 0,
 		 "SELECT tablename from pg_tables WHERE tablename NOT LIKE 'pg_%%' AND tablename NOT LIKE 'sql_%%' ORDER BY tablename");
@@ -515,7 +515,7 @@ int get_db_tables(PGconn* c, char*** dat, int* ntabs, int want_all_elems)
  if (!res) { *dat=NULL; ntabs=0; warn("empty result get_db_tables: %s:%d", __FILE__,__LINE__); return 0; }
  if (col<0 || row<0) { printf("errstr=%s\n", errstr); (*dat) = NULL; *ntabs=-1; return 0; }
  *ntabs = row;
- data = (char**)malloc(row<<2);
+ data = (char**)malloc(row*sizeof(char*));
  for (i=0;i<row;i++) 
    { 
     data[i] = malloc(strlen(res[i][0])+1); 
@@ -533,7 +533,7 @@ int dmget_db_tables(PGconn* c, char*** dat, int* ntabs, int want_all_elems, char
  int row,col,i;
  char errstr[MAX_QUERY_LENGTH+100];
  data = *dat;
- debug("%s:%d mget_db_tables called from %s:%d", __FILE__,__LINE__,file,line);
+ debug("%s:%d mget_db_tables(%d) called from %s:%d", __FILE__,__LINE__,want_all_elems,file,line);
  if (!want_all_elems)
  dmexecute_printf(c, &res, &row, &col, errstr, 0,HERE,
 		 "SELECT tablename from pg_tables WHERE tablename NOT LIKE 'pg_%%' AND tablename NOT LIKE 'sql_%%' ORDER BY tablename");
@@ -543,7 +543,7 @@ int dmget_db_tables(PGconn* c, char*** dat, int* ntabs, int want_all_elems, char
  if (!res) { *dat=NULL; ntabs=0; warn("empty result get_db_tables: %s:%d", __FILE__,__LINE__); return 0; }
  if (col<0 || row<0) { printf("errstr=%s\n", errstr); (*dat) = NULL; *ntabs=-1; return 0; }
  *ntabs = row;
- data = (char**)dmmalloc(row<<2, HERE);
+ data = (char**)dmmalloc(row*sizeof(char*), HERE);
  for (i=0;i<row;i++) 
    { 
     data[i] = dmmalloc(strlen(res[i][0])+1, HERE); 
@@ -561,7 +561,7 @@ int mget_db_tables(PGconn* c, char*** dat, int* ntabs, int want_all_elems)
  int row,col,i;
  char errstr[MAX_QUERY_LENGTH+100];
  data = *dat;
- debug("%s:%d mget_db_tables", __FILE__,__LINE__);
+ debug("%s:%d mget_db_tables(%d)", __FILE__,__LINE__,want_all_elems);
  if (!want_all_elems)
  execute_printf(c, &res, &row, &col, errstr, 0,
 		 "SELECT tablename from pg_tables WHERE tablename NOT LIKE 'pg_%%' AND tablename NOT LIKE 'sql_%%' ORDER BY tablename");
@@ -571,7 +571,7 @@ int mget_db_tables(PGconn* c, char*** dat, int* ntabs, int want_all_elems)
  if (!res) { *dat=NULL; ntabs=0; warn("empty result get_db_tables: %s:%d", __FILE__,__LINE__); return 0; }
  if (col<0 || row<0) { printf("errstr=%s\n", errstr); (*dat) = NULL; *ntabs=-1; return 0; }
  *ntabs = row;
- data = (char**)mmalloc(row<<2);
+ data = (char**)mmalloc(row*sizeof(char*));
  for (i=0;i<row;i++) 
    { 
     data[i] = mmalloc(strlen(res[i][0])+1); 
@@ -589,7 +589,7 @@ int mem_get_db_tables(struct mem_list** mem, PGconn* c, char*** dat, int* ntabs,
  int row,col,i;
  char errstr[MAX_QUERY_LENGTH+100];
  data = *dat;
- debug("%s:%d mem_get_db_tables", __FILE__,__LINE__);
+ debug("%s:%d mem_get_db_tables(%d)", __FILE__,__LINE__,want_all_elems);
  if (!want_all_elems)
  mem_execute_printf(mem,c, &res, &row, &col, errstr, 0,
 		 "SELECT tablename from pg_tables WHERE tablename NOT LIKE 'pg_%%' AND tablename NOT LIKE 'sql_%%' ORDER BY tablename");
@@ -599,7 +599,7 @@ int mem_get_db_tables(struct mem_list** mem, PGconn* c, char*** dat, int* ntabs,
  if (!res) { *dat=NULL; ntabs=0; warn("empty result get_db_tables: %s:%d", __FILE__,__LINE__); return 0; }
  if (col<0 || row<0) { debug("errstr=%s\n", errstr); (*dat) = NULL; *ntabs=-1; return 0; }
  *ntabs = row;
- data = (char**)smalloc(mem, row<<2);
+ data = (char**)smalloc(mem, row*sizeof(char*));
  for (i=0;i<row;i++) 
    { 
     data[i] = smalloc(mem, strlen(res[i][0])+1); 
@@ -617,7 +617,7 @@ int dmem_get_db_tables(struct dmem_list** mem, PGconn* c, char*** dat, int* ntab
  int row,col,i;
  char errstr[MAX_QUERY_LENGTH+100];
  data = *dat;
- debug("%s:%d mem_get_db_tables called from %s:%d", __FILE__,__LINE__,file,line);
+ debug("%s:%d mem_get_db_tables(%d) called from %s:%d", __FILE__,__LINE__,want_all_elems,file,line);
  if (!want_all_elems)
  dmem_execute_printf(mem,c, &res, &row, &col, errstr, 0,HERE,
 		 "SELECT tablename from pg_tables WHERE tablename NOT LIKE 'pg_%%' AND tablename NOT LIKE 'sql_%%' ORDER BY tablename");
@@ -627,7 +627,7 @@ int dmem_get_db_tables(struct dmem_list** mem, PGconn* c, char*** dat, int* ntab
  if (!res) { *dat=NULL; ntabs=0; warn("empty result get_db_tables: %s:%d", __FILE__,__LINE__); return 0; }
  if (col<0 || row<0) { debug("errstr=%s\n", errstr); (*dat) = NULL; *ntabs=-1; return 0; }
  *ntabs = row;
- data = (char**)dsmalloc(mem, row<<2, HERE);
+ data = (char**)dsmalloc(mem, row*sizeof(char*), HERE);
  for (i=0;i<row;i++) 
    { 
     data[i] = dsmalloc(mem, strlen(res[i][0])+1, HERE); 
@@ -643,7 +643,7 @@ PGresult* execute_query(PGconn* c,  char* query)
 {
  PGresult* r;
  int stat;
- debug("%s:%d execute_query", __FILE__,__LINE__);
+ debug("%s:%d execute_query(%s)", __FILE__,__LINE__,query);
  debug("SQLquery: \"%s\"\n", query);
  if (!query)
    {
@@ -673,7 +673,7 @@ char*** dmem_pgres2pc3(struct dmem_list** mem, const PGresult* r, int* a, int* b
  char*** result;
  char* tmp;
  int i,j;
- debug("%s:%d dmem_pgres2pc3 called from %s:%d", __FILE__,__LINE__,file,line);
+ debug("%s:%d dmem_pgres2pc3() called from %s:%d", __FILE__,__LINE__,file,line);
  debug("mem_pgres2pc3: %p\n", (void*)r);
  if (!r) return 0;
  i=j=0;
@@ -688,11 +688,11 @@ char*** dmem_pgres2pc3(struct dmem_list** mem, const PGresult* r, int* a, int* b
  /*if (!(*a) || !(*b)) { warn("no cols or no rows (%s:%d)", __FILE__,__LINE__); return NULL; }*/
  if (!want_meta)
  {
- result = (char***)dsmalloc(mem, (*a)<<2, HERE);
+ result = (char***)dsmalloc(mem, (*a)*sizeof(char**), HERE);
  if (!result) { ERR error("smalloc error\n"); return NULL; }
  for (i=0;i<*a;i++)
    {
-    result[i] = (char**)dsmalloc(mem, (*b)<<2, HERE);
+    result[i] = (char**)dsmalloc(mem, (*b)*sizeof(char*), HERE);
     if (!result[i])
       {
        for (j=0;j<i;j++) dsfree(mem, (void**)(&result[i]), HERE);
@@ -726,11 +726,11 @@ char*** dmem_pgres2pc3(struct dmem_list** mem, const PGresult* r, int* a, int* b
  {
   if ((*b)<=0) return NULL;		/*FIXME is it OK? */
  (*a)++;
- result = (char***)dsmalloc(mem, (*a)<<2, HERE);
+ result = (char***)dsmalloc(mem, (*a)*sizeof(char**), HERE);
  if (!result) { ERR error("smalloc error\n"); return NULL; }
  for (i=0;i<*a;i++)
    {
-    result[i] = (char**)dsmalloc(mem, (*b)<<2, HERE);
+    result[i] = (char**)dsmalloc(mem, (*b)*sizeof(char*), HERE);
     if (!result[i])
       {
        for (j=0;j<i;j++) dsfree(mem, (void**)(&result[i]), HERE);
@@ -766,7 +766,7 @@ char*** mem_pgres2pc3(struct mem_list** mem, const PGresult* r, int* a, int* b,
  char*** result;
  char* tmp;
  int i,j;
- debug("%s:%d mem_pgres2pc3", __FILE__,__LINE__);
+ debug("%s:%d mem_pgres2pc3()", __FILE__,__LINE__);
  debug("mem_pgres2pc3: %p\n", (void*)r);
  if (!r) return 0;
  i=j=0;
@@ -781,11 +781,11 @@ char*** mem_pgres2pc3(struct mem_list** mem, const PGresult* r, int* a, int* b,
  /*if (!(*a) || !(*b)) { warn("no cols or no rows (%s:%d)", __FILE__,__LINE__); return NULL; }*/
  if (!want_meta)
  {
- result = (char***)smalloc(mem, (*a)<<2);
+ result = (char***)smalloc(mem, (*a)*sizeof(char**));
  if (!result) { ERR error("smalloc error\n"); return NULL; }
  for (i=0;i<*a;i++)
    {
-    result[i] = (char**)smalloc(mem, (*b)<<2);
+    result[i] = (char**)smalloc(mem, (*b)*sizeof(char*));
     if (!result[i])
       {
        for (j=0;j<i;j++) sfree(mem, (void**)(&result[i]));
@@ -819,11 +819,11 @@ char*** mem_pgres2pc3(struct mem_list** mem, const PGresult* r, int* a, int* b,
  {
   if ((*b)<=0) return NULL;		/*FIXME is it OK? */
  (*a)++;
- result = (char***)smalloc(mem, (*a)<<2);
+ result = (char***)smalloc(mem, (*a)*sizeof(char**));
  if (!result) { ERR error("smalloc error\n"); return NULL; }
  for (i=0;i<*a;i++)
    {
-    result[i] = (char**)smalloc(mem, (*b)<<2);
+    result[i] = (char**)smalloc(mem, (*b)*sizeof(char*));
     if (!result[i])
       {
        for (j=0;j<i;j++) sfree(mem, (void**)(&result[i]));
@@ -859,7 +859,7 @@ char*** dmpgres2pc3(const PGresult* r, int* a, int* b, int want_meta, char* file
  char*** result;
  char* tmp;
  int i,j;
- debug("%s:%d dmpgres2pc3 called from %s:%d", __FILE__,__LINE__,file,line);
+ debug("%s:%d dmpgres2pc3() called from %s:%d", __FILE__,__LINE__,file,line);
  debug("dmpgres2pc3: %p\n", (void*)r);
  if (!r) return 0;
  i=j=0;
@@ -874,11 +874,11 @@ char*** dmpgres2pc3(const PGresult* r, int* a, int* b, int want_meta, char* file
  /*printf("ntuples=%d,%d\n", *a,*b);*/
  if (!want_meta)
  {
- result = (char***)dmmalloc((*a)<<2, HERE);
+ result = (char***)dmmalloc((*a)*sizeof(char**), HERE);
  if (!result) { ERR error("mmalloc error\n"); return NULL; }
  for (i=0;i<*a;i++)
   {
-    result[i] = (char**)dmmalloc((*b)<<2, HERE);
+    result[i] = (char**)dmmalloc((*b)*sizeof(char*), HERE);
     if (!result[i])
       {
        for (j=0;j<i;j++) 
@@ -915,11 +915,11 @@ char*** dmpgres2pc3(const PGresult* r, int* a, int* b, int want_meta, char* file
  {
   if ((*b)<=0) return NULL;		/*FIXME is it OK? */
  (*a)++;
- result = (char***)dmmalloc((*a)<<2, HERE);
+ result = (char***)dmmalloc((*a)*sizeof(char**), HERE);
  if (!result) { ERR error("mmalloc error\n"); return NULL; }
  for (i=0;i<*a;i++)
    {
-    result[i] = (char**)dmmalloc((*b)<<2, HERE);
+    result[i] = (char**)dmmalloc((*b)*sizeof(char*), HERE);
     if (!result[i])
       {
        for (j=0;j<i;j++) 
@@ -958,7 +958,7 @@ char*** mpgres2pc3(const PGresult* r, int* a, int* b, int want_meta)
  char*** result;
  char* tmp;
  int i,j;
- debug("%s:%d mpgres2pc3", __FILE__,__LINE__);
+ debug("%s:%d mpgres2pc3()", __FILE__,__LINE__);
  debug("mpgres2pc3: %p\n", (void*)r);
  if (!r) return 0;
  i=j=0;
@@ -973,11 +973,11 @@ char*** mpgres2pc3(const PGresult* r, int* a, int* b, int want_meta)
  /*printf("ntuples=%d,%d\n", *a,*b);*/
  if (!want_meta)
  {
- result = (char***)mmalloc((*a)<<2);
+ result = (char***)mmalloc((*a)*sizeof(char**));
  if (!result) { ERR error("mmalloc error\n"); return NULL; }
  for (i=0;i<*a;i++)
   {
-    result[i] = (char**)mmalloc((*b)<<2);
+    result[i] = (char**)mmalloc((*b)*sizeof(char*));
     if (!result[i])
       {
        for (j=0;j<i;j++) 
@@ -1014,11 +1014,11 @@ char*** mpgres2pc3(const PGresult* r, int* a, int* b, int want_meta)
  {
   if ((*b)<=0) return NULL;		/*FIXME is it OK? */
  (*a)++;
- result = (char***)mmalloc((*a)<<2);
+ result = (char***)mmalloc((*a)*sizeof(char**));
  if (!result) { ERR error("mmalloc error\n"); return NULL; }
  for (i=0;i<*a;i++)
    {
-    result[i] = (char**)mmalloc((*b)<<2);
+    result[i] = (char**)mmalloc((*b)*sizeof(char*));
     if (!result[i])
       {
        for (j=0;j<i;j++) 
@@ -1057,7 +1057,7 @@ char*** pgres2pc3(const PGresult* r, int* a, int* b, int want_meta)
  char*** result;
  char* tmp;
  int i,j;
- debug("%s:%d pgres2pc3", __FILE__,__LINE__);
+ debug("%s:%d pgres2pc3()", __FILE__,__LINE__);
  debug("pgres2pc3: %p\n", (void*)r);
  if (!r) return 0;
  i=j=0;
@@ -1071,11 +1071,11 @@ char*** pgres2pc3(const PGresult* r, int* a, int* b, int want_meta)
  /*printf("ntuples=%d,%d\n", *a,*b);*/
  if (!want_meta)
  {
- result = (char***)malloc((*a)<<2);
+ result = (char***)malloc((*a)*sizeof(char**));
  if (!result) { ERR error("malloc error\n"); return NULL; }
  for (i=0;i<*a;i++)
    {
-    result[i] = (char**)malloc((*b)<<2);
+    result[i] = (char**)malloc((*b)*sizeof(char*));
     if (!result[i])
       {
        for (j=0;j<i;j++) free(result[i]);
@@ -1109,11 +1109,11 @@ char*** pgres2pc3(const PGresult* r, int* a, int* b, int want_meta)
  {
   if ((*b)<=0) return NULL;		/*FIXME is it OK? */
  (*a)++;
- result = (char***)malloc((*a)<<2);
+ result = (char***)malloc((*a)*sizeof(char**));
  if (!result) { ERR error("malloc error\n"); return NULL; }
  for (i=0;i<*a;i++)
    {
-    result[i] = (char**)malloc((*b)<<2);
+    result[i] = (char**)malloc((*b)*sizeof(char*));
     if (!result[i])
       {
        for (j=0;j<i;j++) free(result[i]);
@@ -1147,7 +1147,7 @@ char*** pgres2pc3(const PGresult* r, int* a, int* b, int want_meta)
 void mem_free_p3c(struct mem_list** mem, char**** p, int a, int b)
 {
  int i,j;
- debug("%s:%d mem_free_p3c", __FILE__,__LINE__);
+ debug("%s:%d mem_free_p3c()", __FILE__,__LINE__);
  debug("mem_free_p3c: ****p=%p, a=%d, b=%d\n",(void*)p,a,b);
  if (!(*p)) return ;
  for (i=0;i<a;i++) if (!(*p)[i]) return ;
@@ -1160,7 +1160,7 @@ void mem_free_p3c(struct mem_list** mem, char**** p, int a, int b)
 void dmem_free_p3c(struct dmem_list** mem, char**** p, int a, int b, char* file, int line)
 {
  int i,j;
- debug("%s:%d dmem_free_p3c called from %s:%d", __FILE__,__LINE__,file,line);
+ debug("%s:%d dmem_free_p3c() called from %s:%d", __FILE__,__LINE__,file,line);
  debug("dmem_free_p3c: ****p=%p, a=%d, b=%d\n",(void*)p,a,b);
  if (!(*p)) return ;
  for (i=0;i<a;i++) if (!(*p)[i]) return ;
@@ -1173,7 +1173,7 @@ void dmem_free_p3c(struct dmem_list** mem, char**** p, int a, int b, char* file,
 void mfree_p3c(char**** p, int a, int b)
 {
  int i,j;
- debug("%s:%d mfree_p3c", __FILE__,__LINE__);
+ debug("%s:%d mfree_p3c()", __FILE__,__LINE__);
  debug("mfree_p3c: ****p=%p, a=%d, b=%d\n",(void*)p,a,b);
  if (!(*p)) return ;
  for (i=0;i<a;i++) if (!(*p)[i]) return ;
@@ -1186,7 +1186,7 @@ void mfree_p3c(char**** p, int a, int b)
 void dmfree_p3c(char**** p, int a, int b, char* file, int line)
 {
  int i,j;
- debug("%s:%d dmfree_p3c called from: %s:%d", __FILE__,__LINE__,file,line);
+ debug("%s:%d dmfree_p3c() called from: %s:%d", __FILE__,__LINE__,file,line);
  debug("dmfree_p3c: ****p=%p, a=%d, b=%d\n",(void*)p,a,b);
  if (!(*p)) return ;
  for (i=0;i<a;i++) if (!(*p)[i]) return ;
@@ -1199,7 +1199,7 @@ void dmfree_p3c(char**** p, int a, int b, char* file, int line)
 void free_p3c(char**** p, int a, int b)
 {
  int i,j;
- debug("%s:%d free_p3c", __FILE__,__LINE__);
+ debug("%s:%d free_p3c()", __FILE__,__LINE__);
  debug("free_p3c: ****p=%p, a=%d, b=%d\n",(void*)p,a,b);
  if (!(*p)) return ;
  for (i=0;i<a;i++) if (!(*p)[i]) return ;
