@@ -748,6 +748,7 @@ struct parser_data parser[NUM_PARSE_STRINGS] = {
 int get_last_words(char* target, char* from, int count)
 {
  int i,l,offset,cnt;
+ debug("%s:%d get_last_words(%s,%s,%d)", __FILE__,__LINE__,target?target:"null",from?from:"null",count);
  l = strlen(from);
  i = l-1;
  offset=0;
@@ -775,6 +776,7 @@ int get_last_words(char* target, char* from, int count)
 int auto_complete(char* str, char*** table)
 {
  int count,i,j, len;
+ debug("%s:%d auto_complete(%s, %p)", __FILE__,__LINE__,str?str:"null",table);
  count = 0;
  *table = NULL;
  len = strlen(str);
