@@ -419,6 +419,75 @@ static const char * xpm_dview[] =
 "                ",
 };
 
+static const char * xpm_dins[] =
+{
+"16 16 2 1",
+"       c None",
+"c      c #0000AAAA0000",
+"cc  cc          ",
+" cc  cc         ",
+"  cc  cc        ",
+"   cc  cc       ",
+"    cc  cc      ",
+"     cc  cc     ",
+"      cc  cc    ",
+"       cc  cc   ",
+"       cc  cc   ",
+"      cc  cc    ",
+"     cc  cc     ",
+"    cc  cc      ",
+"   cc  cc       ",
+"  cc  cc        ",
+" cc  cc         ",
+"cc  cc          ",
+};
+
+static const char * xpm_ddel[] =
+{
+"16 16 2 1",
+"       c None",
+"c      c #AAAA00000000",
+"          cc  cc",
+"         cc  cc ",
+"        cc  cc  ",
+"       cc  cc   ",
+"      cc  cc    ",
+"     cc  cc     ",
+"    cc  cc      ",
+"   cc  cc       ",
+"   cc  cc       ",
+"    cc  cc      ",
+"     cc  cc     ",
+"      cc  cc    ",
+"       cc  cc   ",
+"        cc  cc  ",
+"         cc  cc ",
+"          cc  cc",
+};
+
+static const char * xpm_dwiz[] =
+{
+"16 16 2 1",
+"       c None",
+"c      c #FFFFCCCC0000",
+"        c    c  ",
+"       ccc  cc  ",
+"      cccccccc  ",
+"     ccccccccc  ",
+"      ccccccccc ",
+" ccccccccccccc  ",
+"ccccccccccccccc ",
+"   ccccccccccccc",
+"    ccccccccccc ",
+"   ccccccccccc  ",
+"  ccccccccc     ",
+" ccc   ccccc    ",
+"ccc      cccc   ",
+"cc         ccc  ",
+"                ",
+"                ",
+};
+
 
 void get_toolbar(GtkWidget* w, GtkWidget **tb);
 void about_window_new();
@@ -705,7 +774,7 @@ static char *xpm_big[] =
 
 int about_clback(GtkWidget* w, gpointer d)
 {
- debug("%s:%d about_clback", __FILE__,__LINE__);
+ debug("%s:%d about_clback()", __FILE__,__LINE__);
  gtk_main_quit();
  return FALSE;
 }
@@ -718,7 +787,7 @@ void about_window_new()
  GtkStyle *style;
  GdkColormap* gcm;
  GdkBitmap *mask;
- debug("%s:%d about_window_new", __FILE__,__LINE__);
+ debug("%s:%d about_window_new()", __FILE__,__LINE__);
  window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
  gtk_window_set_modal(GTK_WINDOW(window), 1);
  gtk_widget_set_usize (GTK_WIDGET(window), 400, 300);
@@ -770,7 +839,7 @@ void get_toolbar(GtkWidget* w, GtkWidget **tb)
  GtkStyle *style;
  GtkWidget* pix;
  GdkColormap* gcm;
- debug("%s:%d get_toolbar", __FILE__,__LINE__);
+ debug("%s:%d get_toolbar()", __FILE__,__LINE__);
  *tb = gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL, GTK_TOOLBAR_ICONS);
  gtk_toolbar_set_tooltips(GTK_TOOLBAR(*tb), TRUE);
  gtk_container_set_border_width(GTK_CONTAINER(*tb), 5);
@@ -828,19 +897,39 @@ void get_toolbar(GtkWidget* w, GtkWidget **tb)
 	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_ctable);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Create table wizard", "Private",pix,create_table,NULL);
+ 
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
 	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_dtable);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Drop table(s)", "Private",pix,tdrop_table,NULL);
+ 
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
 	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_dview);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Drop view(s)", "Private",pix,tdrop_view,NULL); 
+ 
+ pix_new = gdk_pixmap_colormap_create_from_xpm_d
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_dins);
+ pix = gtk_pixmap_new(pix_new, mask);
+ gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Insert", "Private",pix,tinsert,NULL); 
+ 
+ pix_new = gdk_pixmap_colormap_create_from_xpm_d
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_ddel);
+ pix = gtk_pixmap_new(pix_new, mask);
+ gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Delete", "Private",pix,tdelete,NULL); 
  gtk_toolbar_append_space(GTK_TOOLBAR(*tb));
+ 
+ pix_new = gdk_pixmap_colormap_create_from_xpm_d
+	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_dwiz);
+ pix = gtk_pixmap_new(pix_new, mask);
+ gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "Wizards", "Private",pix,wizards,NULL); 
+ gtk_toolbar_append_space(GTK_TOOLBAR(*tb));
+ 
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
 	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_about);
  pix = gtk_pixmap_new(pix_new, mask);
  gtk_toolbar_append_item(GTK_TOOLBAR(*tb), NULL, "About", "Private",pix,about_box,NULL);
+ 
  pix_new = gdk_pixmap_colormap_create_from_xpm_d
 	 (w->window,gcm,&mask,&style->bg[GTK_STATE_NORMAL],(gchar **)xpm_quit);
  pix = gtk_pixmap_new(pix_new, mask);
