@@ -15,14 +15,15 @@
 
 extern PGconn* connection;
 extern int want_all_elems;
-
+static struct WizData wdata;
 
 static char* qptr = NULL;
 static struct PassInsertData pidata;
+static int wizstep = 0;
 
 int abort_query(GtkWidget* w, gpointer data)
 {
- debug("%s:%d abort_query",__FILE__,__LINE__);
+ debug("%s:%d abort_query()",__FILE__,__LINE__);
  gtk_main_quit();
  if (qptr) free(qptr);
  qptr = NULL;
@@ -31,7 +32,7 @@ int abort_query(GtkWidget* w, gpointer data)
 
 void update_pidata(GtkWidget* w, gpointer data)
 {
- debug("%s:%d update_pidata",__FILE__,__LINE__);
+ debug("%s:%d update_pidata()",__FILE__,__LINE__);
  int i;
  int idx = (int)data;
  strcpy(pidata.values[idx], gtk_entry_get_text(GTK_ENTRY(w)));
@@ -43,7 +44,7 @@ void update_pidata(GtkWidget* w, gpointer data)
 
 void update_pidata_combo(GtkWidget* w, gpointer data)
 {
- debug("%s:%d update_pidata_combo",__FILE__,__LINE__);
+ debug("%s:%d update_pidata_combo()",__FILE__,__LINE__);
  int i;
  int idx = (int)data;
  char* ctext = gtk_entry_get_text(GTK_ENTRY(w));
@@ -62,7 +63,7 @@ void update_pidata_combo(GtkWidget* w, gpointer data)
 
 void generate_delete_query(GtkWidget* w, gpointer data)
 {
- debug("%s:%d generate_delete_query",__FILE__,__LINE__);
+ debug("%s:%d generate_delete_query()",__FILE__,__LINE__);
  int nbytes;
  int i,n,x;
  int ins;
@@ -147,7 +148,7 @@ void generate_delete_query(GtkWidget* w, gpointer data)
 
 void generate_insert_query(GtkWidget* w, gpointer data)
 {
- debug("%s:%d generate_insert_query",__FILE__,__LINE__);
+ debug("%s:%d generate_insert_query()",__FILE__,__LINE__);
  int nbytes;
  int i,n;
  int ins;
@@ -211,6 +212,7 @@ void generate_insert_query(GtkWidget* w, gpointer data)
 void free_pidata()
 {
  int x,i;
+ debug("%s:%d free_pixdata()", __FILE__,__LINE__);
  x = pidata.n;
  for (i=0;i<x;i++)
  {
@@ -230,7 +232,7 @@ char* insert_wizard(char* tabname)
  char errstr[MAX_QUERY_LENGTH+100];
  int i;
  GtkWidget* window, *table, *entry, *button, *label, *scroller_view, *vbox;
- debug("%s:%d insert_wizard",__FILE__,__LINE__);
+ debug("%s:%d insert_wizard(%s)",__FILE__,__LINE__,tabname?tabname:"null");
  if (!connection) error("no_connection %s:%d", __FILE__,__LINE__);
 #ifdef SMALLOC
  dmexecute_printf(connection, &ptr, &row, &col, errstr, 1, HERE, "SELECT * FROM %s", tabname);
@@ -262,6 +264,7 @@ char* insert_wizard(char* tabname)
   pidata.values[i] = (char*)malloc(MAX_INSERT_STR_LENGTH+1);
   if (!pidata.values[i]) fatal_here(HERE, "malloc failed");
   strcpy(pidata.values[i], "");
+  pidata.types[i] = -1;
  }
  for (i=0;i<col;i++)
  {
@@ -313,7 +316,7 @@ char* delete_wizard(char* tabname)
  int i;
  GtkWidget* window, *table, *entry, *button, *label, *scroller_view, *vbox, *combo;
  GList* list;
- debug("%s:%d insert_wizard",__FILE__,__LINE__);
+ debug("%s:%d delete_wizard(%s)",__FILE__,__LINE__,tabname?tabname:"null");
  if (!connection) error("no_connection %s:%d", __FILE__,__LINE__);
 #ifdef SMALLOC
  dmexecute_printf(connection, &ptr, &row, &col, errstr, 1, HERE, "SELECT * FROM %s", tabname);
@@ -408,7 +411,7 @@ char* delete_wizard(char* tabname)
 
 gint delete_combos_proc_wiz(GtkWidget* w, gpointer d)
 {
- debug("%s:%d delete_combos_proc_wiz",__FILE__,__LINE__);
+ debug("%s:%d delete_combos_proc_wiz()",__FILE__,__LINE__);
  gtk_main_quit();
  if (qptr) free(qptr);
  qptr = NULL;
@@ -417,7 +420,7 @@ gint delete_combos_proc_wiz(GtkWidget* w, gpointer d)
 
 void ok_combo_proc_wiz(GtkWidget* w, gpointer cmb)
 {
- debug("%s:%d ok_combo_proc_wiz",__FILE__,__LINE__);
+ debug("%s:%d ok_combo_proc_wiz()",__FILE__,__LINE__);
  if (!cmb) return;
  strcpy(qptr,gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(cmb)->entry)));
  gtk_main_quit();
@@ -426,6 +429,7 @@ void ok_combo_proc_wiz(GtkWidget* w, gpointer cmb)
 int setup_combo_views(PGconn* c, GtkWidget* w, GtkWidget** cmb)
 {
  char errstr[MAX_QUERY_LENGTH];
+ debug("%s:%d setup_combo_views()", __FILE__,__LINE__);
  int row,col,i;
  char*** ptr;
  char* tmps;
@@ -477,9 +481,10 @@ int setup_combo_views(PGconn* c, GtkWidget* w, GtkWidget** cmb)
  return 0;
 }
 
-int setup_combo_tables(PGconn* c, GtkWidget* w, GtkWidget** cmb)
+int setup_combo_tables(PGconn* c, GtkWidget* w, GtkWidget** cmb, int all_opt)
 {
  char errstr[MAX_QUERY_LENGTH];
+ debug("%s:%d setup_combo_tables(%d)", __FILE__,__LINE__, all_opt);
  int row,col,i;
  char*** ptr;
  GList* list;
@@ -506,7 +511,7 @@ int setup_combo_tables(PGconn* c, GtkWidget* w, GtkWidget** cmb)
   return -1;
  }
  for (i=0;i<row;i++) list = g_list_append(list, ptr[i][0]);
- list = g_list_append(list,"*all*");
+ if (all_opt) list = g_list_append(list,"*all*");
  *cmb = gtk_combo_new();
  gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(*cmb)->entry),ptr[0][0]);
  gtk_entry_set_editable(GTK_ENTRY(GTK_COMBO(*cmb)->entry), FALSE);
@@ -517,12 +522,12 @@ int setup_combo_tables(PGconn* c, GtkWidget* w, GtkWidget** cmb)
 }
 
 
-char* select_table_wizard()
+char* select_table_wizard(int all_opt)
 {
  GtkWidget* dialog, *combo, *button, *label;
  qptr = (char*)malloc(MAX_TABLE_NAME+1);
  if (!qptr) fatal_here(HERE, "malloc failed");
- debug("%s:%d select_table_wizard",__FILE__,__LINE__);
+ debug("%s:%d select_table_wizard(%d)",__FILE__,__LINE__,all_opt);
  if (!connection) error("select_table_wizard: %s:%d", __FILE__,__LINE__);
  dialog = gtk_dialog_new();
  gtk_window_set_title(GTK_WINDOW(dialog),"Select table");
@@ -533,7 +538,7 @@ char* select_table_wizard()
  gtk_widget_show(label);
  button = gtk_button_new_with_label("Select");
  combo=NULL;
- if (setup_combo_tables(connection, dialog, &combo)==-1) 
+ if (setup_combo_tables(connection, dialog, &combo, all_opt)==-1) 
  {
 	 free(qptr);
 	 qptr = NULL;
@@ -558,7 +563,7 @@ char* select_view_wizard()
  GtkWidget* dialog, *combo, *button, *label;
  qptr = (char*)malloc(MAX_TABLE_NAME+1);
  if (!qptr) fatal_here(HERE, "malloc failed");
- debug("%s:%d select_view_wizard",__FILE__,__LINE__);
+ debug("%s:%d select_view_wizard()",__FILE__,__LINE__);
  if (!connection) error("select_view_wizard: %s:%d", __FILE__,__LINE__);
  dialog = gtk_dialog_new();
  gtk_window_set_title(GTK_WINDOW(dialog),"Select view");
@@ -570,11 +575,11 @@ char* select_view_wizard()
  button = gtk_button_new_with_label("Select");
  combo=NULL;
  if (setup_combo_views(connection, dialog, &combo)==-1)
- {
-	 free(qptr);
-	 qptr = NULL;
-	 return NULL;
- }
+   {
+    free(qptr);
+    qptr = NULL;
+    return NULL;
+   }
  gtk_entry_set_max_length(GTK_ENTRY(GTK_COMBO(combo)->entry), MAX_TABLE_NAME);
  gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->action_area), combo, TRUE, TRUE, 0);
  gtk_widget_show(combo);
@@ -589,3 +594,173 @@ char* select_view_wizard()
  return qptr;
 }
 
+
+int gtk_scale_get_value(GtkWidget* w, gpointer ptr)	//SIZEOF(GFLOAT) CAN BE MORE THAN SIZEOF(GPOINTER)
+{
+ GtkAdjustment* adj;
+ debug("%s:%d gtk_scale_get_value()",__FILE__,__LINE__);
+ adj = gtk_range_get_adjustment(GTK_RANGE(&(GTK_SCALE(ptr)->range)));
+ return (int)(adj->value);
+}
+
+void gtk_scale_set_value(GtkWidget* scale, gfloat val)
+{
+ debug("%s:%d gtk_scale_set_value(%f)",__FILE__,__LINE__,val);
+ GtkObject* adj;
+ adj = gtk_adjustment_new(0.0,0.0,49.0, 1.0, 1.0, 1.0);
+ gtk_adjustment_set_value(GTK_ADJUSTMENT(adj), val);
+ gtk_range_set_adjustment(GTK_RANGE(&(GTK_SCALE(scale)->range)), GTK_ADJUSTMENT(adj));
+}
+
+void scale_changed_func(GtkWidget* scale, gfloat dummy)
+{
+ debug("%s:%d scale_changed_func()",__FILE__,__LINE__);
+ GtkWidget* label;
+ int val = gtk_scale_get_value(wdata.scale, wdata.scale);
+ if (val)
+   {
+    gtk_widget_destroy(wdata.label2);
+    label = gtk_label_new("Select number of columns (1-48):\nSelect 0 if you want to\nLoad prepared table from file");
+    wdata.label2 = label;
+    gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
+    gtk_widget_show(label);
+    gtk_table_attach(GTK_TABLE(wdata.table), label, 0, 50, 0, 30, GTK_FILL|GTK_EXPAND,GTK_FILL|GTK_EXPAND, 0, 0);
+   }
+ else
+   {
+    gtk_widget_destroy(wdata.label2);
+    label = gtk_label_new("Select number of columns (1-48):\nYou have selcted 0 as number of columns\nTable will be loaded from file in next step");
+    wdata.label2 = label;
+    gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
+    gtk_widget_show(label);
+    gtk_table_attach(GTK_TABLE(wdata.table), label, 0, 50, 0, 30, GTK_FILL|GTK_EXPAND,GTK_FILL|GTK_EXPAND, 0, 0);
+   }
+}
+
+void prev_ctable_func(GtkWidget* w, gpointer data)
+{
+ debug("%s:%d prev_ctable_func()", __FILE__,__LINE__);
+ GtkWidget* tab = *((GtkWidget**)(data));
+ GtkWidget* label;
+ switch (wizstep)
+ {
+  case 0:
+  	if (gtk_dialog_yes_no_printf("Going back at first step\nmeans closing Wizard. OK?"))
+   	  {
+    	   qptr = NULL;
+    	   gtk_main_quit();
+           return;
+   	  }
+	break;
+  case 1:
+	    gtk_widget_destroy(wdata.label2);
+	    wdata.ncols = gtk_scale_get_value(wdata.scale, wdata.scale);
+	    gtk_widget_destroy(wdata.scale);
+ 	    label = gtk_label_new("Welcome to Create Table Wizard\nthis wizard will guide You\nthrough the rest of Create Table process\nGood luck!");
+ 	    gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_FILL);
+	    gtk_table_attach(GTK_TABLE(tab), label, 0, 50, 0, 50, GTK_FILL,GTK_FILL, 0, 0);
+   	    gtk_widget_show(label);
+            wdata.label = label;
+	    wizstep--;
+	    break;
+  default:
+	    gtk_dialog_printf("Not implemented!");
+	    qptr = NULL;
+	    gtk_main_quit();
+	    return;
+ }
+}
+
+
+void next_ctable_func(GtkWidget* w, gpointer data)
+{
+ debug("%s:%d next_ctable_func()", __FILE__,__LINE__);
+ GtkWidget *scale, *label;
+ GtkObject *adj;
+ GtkWidget* tab = *((GtkWidget**)(data));
+ switch (wizstep)
+   {
+    case 0:
+	    gtk_widget_destroy(wdata.label);
+ 	    adj = gtk_adjustment_new(0.0,0.0,49.0, 1.0, 1.0, 1.0);
+	    scale = gtk_hscale_new(GTK_ADJUSTMENT(adj));
+	    gtk_scale_set_digits(GTK_SCALE(scale), 0);
+	    gtk_scale_set_value(scale, (gfloat)wdata.ncols);
+	    gtk_scale_set_draw_value(GTK_SCALE(scale), TRUE);
+	    gtk_scale_set_value(scale, (gfloat)(wdata.ncols));
+	    gtk_widget_show(scale);
+	    wdata.scale = scale;
+ 	    gtk_table_attach(GTK_TABLE(tab), scale, 0, 50, 30, 50, GTK_FILL,GTK_FILL|GTK_EXPAND, 0, 0);
+ 	    label = gtk_label_new("Select number of columns (1-48):\nSelect 0 if you want to\nLoad prepared table from file");
+	    wdata.label2 = label;
+ 	    gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
+ 	    gtk_table_attach(GTK_TABLE(tab), label, 0, 50, 0, 30, GTK_FILL|GTK_EXPAND,GTK_FILL|GTK_EXPAND, 0, 0);
+	    gtk_widget_show(label);
+	    gtk_widget_show(tab);
+ 	    gtk_signal_connect(GTK_OBJECT(adj), "value_changed", GTK_SIGNAL_FUNC(scale_changed_func), NULL);
+	    wizstep++;
+	    break;
+    default:
+	    gtk_dialog_printf("Not implemented!");
+	    qptr = NULL;
+	    gtk_main_quit();
+	    return;
+   }
+}
+
+void init_wdata()
+{
+ debug("%s:%d init_wdata()", __FILE__,__LINE__);
+ wdata.ncols = 4;
+ wdata.label = wdata.label2 = wdata.scale = wdata.table = NULL;
+}
+
+char* ctable_wizard()
+{
+ debug("%s:%d ctable_wizard()", __FILE__,__LINE__);
+ if (qptr) free(qptr);
+ qptr = NULL;
+ wizstep = 0;
+ init_wdata();
+ GtkWidget* window, *table, *button_next, *button_prev, *scroller_view, *vbox, *hbox, *label;
+ window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+ gtk_widget_set_usize(GTK_WIDGET(window), 500, 400);
+ gtk_container_set_border_width(GTK_CONTAINER(window), 5);
+ table = gtk_table_new(50, 50, FALSE);
+ label = gtk_label_new("Welcome to Create Table Wizard\nthis wizard will guide You\nthrough the rest of Create Table process\nGood luck!");
+ gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_FILL);
+ gtk_table_attach(GTK_TABLE (table), label, 0, 4, 0, 4, GTK_FILL,GTK_FILL, 0, 0);
+ gtk_widget_show(label);
+ wdata.label = label;
+ gtk_widget_show(table);
+ scroller_view = gtk_scrolled_window_new(NULL,NULL);
+ gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroller_view), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+ gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scroller_view), table);
+ gtk_container_set_border_width(GTK_CONTAINER(scroller_view), 2);
+ gtk_scrolled_window_set_placement(GTK_SCROLLED_WINDOW(scroller_view), GTK_CORNER_TOP_RIGHT);
+ gtk_widget_show(scroller_view);
+ button_prev = gtk_button_new_with_label("Previous");
+ gtk_widget_show(button_prev);
+ button_next = gtk_button_new_with_label("Next");
+ gtk_widget_show(button_next);
+ vbox = gtk_vbox_new(FALSE, 1);
+ hbox = gtk_hbox_new(FALSE, 1);
+ gtk_box_pack_start(GTK_BOX(hbox),button_prev,  TRUE, TRUE, 0);
+ gtk_box_pack_start(GTK_BOX(hbox),button_next,  TRUE, TRUE, 0);
+ gtk_widget_show(hbox);
+ gtk_box_pack_start(GTK_BOX(vbox),scroller_view,  TRUE, TRUE, 0);
+ gtk_box_pack_start(GTK_BOX(vbox),hbox, FALSE, FALSE, 0);
+ gtk_widget_show(vbox);
+ gtk_container_add(GTK_CONTAINER(window), vbox);
+ gtk_window_set_title(GTK_WINDOW(window), "Create Table Wizard");
+ gtk_window_set_modal(GTK_WINDOW(window), TRUE);
+ gtk_widget_show(window);
+ gtk_signal_connect(GTK_OBJECT(window), "delete_event", GTK_SIGNAL_FUNC(abort_query),(gpointer)(window));
+ gtk_signal_connect(GTK_OBJECT(button_prev), "clicked", GTK_SIGNAL_FUNC(prev_ctable_func), (gpointer)(&table));
+ gtk_signal_connect(GTK_OBJECT(button_next), "clicked", GTK_SIGNAL_FUNC(next_ctable_func), (gpointer)(&table));
+ wdata.table = table;
+ gtk_main();
+ destroy_widget(window);
+ return qptr;
+}
+
