@@ -31,9 +31,19 @@ struct PassInsertData
  int*   types;
 };
 
+struct WizData
+{
+ GtkWidget* label;
+ GtkWidget* label2;
+ GtkWidget* scale;
+ GtkWidget* table;
+ int ncols;
+};
+
 char* insert_wizard(char* tabname);
 char* delete_wizard(char* tabname);
-char* select_table_wizard();
+char* select_table_wizard(int all_opt);
 char* select_view_wizard();
+char* ctable_wizard();
 
 #endif
